<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ControlCenter</name>
    <message>
        <location filename="../qml/ControlCenter.qml" line="188"/>
        <source>Wi-Fi</source>
        <translation>Wi-Fi</translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="191"/>
        <location filename="../qml/ControlCenter.qml" line="214"/>
        <source>On</source>
        <translation>Włączony</translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="191"/>
        <location filename="../qml/ControlCenter.qml" line="203"/>
        <location filename="../qml/ControlCenter.qml" line="214"/>
        <source>Off</source>
        <translation>Wyłączony</translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="202"/>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="213"/>
        <source>Dark Mode</source>
        <translation>Tryb ciemny</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="71"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
</TS>
